#!/bin/sh

# Install script for FireScope Agent for Linux

#FSA-485 Agent installer erroring out on bash version 4.*
if( [ "4" == "${BASH_VERSINFO[0]}" ] )
then
    shopt -s compat31
fi

####################################################################################################
# Variables
####################################################################################################
INSTALLERLOG="/var/tmp/firescope_agent_install.log"
VERSION=4.0.51
FSMUSER="root"
FSMGROUP="root"
FSUSER="firescop"
FSGROUP="firescop"
CURDIR=`pwd`
BASEDIR="/opt/firescope"
JAVAMIN="6"
JAVAMAX="8"
JAVAPATH=`which java 2>> $INSTALLERLOG`
APORT="8042"
SPORT="8043"
MPORT="8044"
JPORT="8046"
DACTIVE="0"
RUNASFIRESCOP="1"
UPGRADE="0"
JMX="false"
RMTCMD="1"
REALTIME="1"
STORETIME="300"
STORECOUNT="100"
INIT="/etc/init.d"
INSTALLER="FireScope_Agent_Installer.sh"
OSNAME="UNSUPPORTED OS"
COPYFROM=""
COPYTO=""
export PATH=$PATH:/bin/:/sbin/:/usr/bin/:/usr/sbin/:/usr/local/bin/:/usr/local/sbin/
####################################################################################################
# End - Variables
####################################################################################################
####################################################################################################
# functions
####################################################################################################
	
	############################################################################################
	# FireScope Agent Help Function
	############################################################################################
	function show_help () {
		HELPUSAGE="$INSTALLER -A XXX.XXX.XXX.XXX [ options ]"
		HELPAPPLIANCE="-A : Appliance IP or DNS name. Usage FireScope_Agent_Installer.sh -a XXX.XXX.XXX.XXX(Required - IP or DNS Name to FireScope Appliance.)"
		HELPBASEINTALLPATH="-b : InstallPath - Path to install the FireScope Agent. default - /opt/firescope"
		HELPREMOTECOMMAND="-c : RemoteCommand - Allows the FireScope Appliance to send commands to the agent to execute. default 0 (Valid 1 on - 0 off)"
		HELPDISABLEACTIVE="-d : DisableActive - Disables Active checks. default 0 (Valid 1 on - 0 off)"
		HELPHELP="-h : Help - Displays this help file"
		HELPHOSTNAME="-H : CINAME - Hostname or name used to ID the system in the FireScope Appliance. Must match for AgentRemote to work properly."
		HELPENABLEJMX="-J : JMXDelegate - Enables the JMX Delegate feature for this agent. default - false (valid true or false)"
		HELPJMXPORT="-j : JMXDelegate Port - Port used by the JMX Delegate. default - 8046 (Valid 1-65535)"
		HELPJAVAMEMMIN="-k : Java Heap Minimum size - the Minimum heap size in MB used by Java. default - 2"
		HELPJAVAMEMMAX="-K : Java Heap Maximum size - the Maximum heap size in MB used by Java. default - 5"
		HELPMANAGERPORT="-m : ManagerPort - Port used by the agent manager to receive data from the FireScope Appliance. default - 8044 (Valid 1-65535)"
		HELPSTORECOUNT="-n : Storecount - Used in Store&Foward mode. The number of metrics stored before sending. default - 100 (valid 10-200)"
		HELPAGENTPORT="-p : AgentPort - Port used by the agent to receive data from the FireScope Appliance. default - 8042 (Valid 1-65535)"
		HELPREALTIME="-s : Realtime - Sets the FireScope Agent to realtime mode. default - 1 (Valid 1-Realtime 0-Store&Forward)"
		HELPSTORETIME="-t : Storetime - Used in Store&Foward mode. The amount of time in seconds that the agent will cache metrics before sending. default - 300 (Valid 30 - 600)"
		HELPUPGRADE="-u : Upgrade - Used to upgrade a legacy firescope_agentd.conf to a firescope_agentd_posix.xml"
		HELPJVM="-V : JVM location - path to the Java Virtual Machine to be used by the JMXDelegate"
		HELPEXAMPLE="e.g. $INSTALLER -A 10.0.2.40 -b /opt/firescope -p 8042 -c 1 -H myserver -s 1 -t 200 -n 400"
		SHOW_HELP="$HELPUSAGE\n\t$HELPAPPLIANCE\n\t$HELPBASEINTALLPATH\n\t$HELPREMOTECOMMAND\n\t$HELPDISABLEACTIVE\n\t$HELPHELP\n\t$HELPHOSTNAME\n\t$HELPENABLEJMX\n\t$HELPJMXPORT\n\t$HELPJAVAMEMMIN\n\t$HELPJAVAMEMMAX\n\t$HELPMANAGERPORT\n\t$HELPSTORECOUNT\n\t$HELPAGENTPORT\n\t$HELPREALTIME\n\t$HELPSTORETIME\n\t$HELPUPGRADE\n\t$HELPJVM\n\t$HELPEXAMPLE"
		echo -e "$SHOW_HELP"
		exit 1
	}
	############################################################################################
	# Resolve the location executables
	############################################################################################
	function resolve_Executables () {
		#-----------------------------------------------------------------
		# Resolve the location of the 'ps' command
		#-----------------------------------------------------------------
		PSEXE="/usr/bin/ps"
		if [ ! -x "$PSEXE" ]
		then
			PSEXE="/bin/ps"
			if [ ! -x "$PSEXE" ]
			then
				echo "Unable to locate 'ps'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
			DATE=`/bin/date` 
		else
			DATE=`/usr/bin/date` 
		fi
		PSKEYWORD="args"

		#-----------------------------------------------------------------
		# Resolve the location of the 'uname' command
		#-----------------------------------------------------------------
		UNAMEEXE="/usr/bin/uname"
		if [ ! -x "$UNAMEEXE" ]
		then
			UNAMEEXE="/bin/uname"
			if [ ! -x "$UNAMEEXE" ]
			then
				echo "Unable to locate 'uname'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'id' command
		#-----------------------------------------------------------------
		IDEXE="/usr/bin/id"
		if [ ! -x "$IDEXE" ]
		then
			IDEXE="/bin/id"
			if [ ! -x "$IDEXE" ]
			then
				echo "Unable to locate 'id'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'cut' command
		#-----------------------------------------------------------------
		CUTEXE="/usr/bin/cut"
		if [ ! -x "$CUTEXE" ]
		then
			CUTEXE="/bin/cut"
			if [ ! -x "$CUTEXE" ]
			then
				echo "Unable to locate 'cut'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		WHOAMI=`$IDEXE | $CUTEXE -d "(" -f2 | $CUTEXE -d ")" -f1`

		#-----------------------------------------------------------------
		# Resolve the location of the 'cat' command
		#-----------------------------------------------------------------
		CATEXE="/usr/bin/cat"
		if [ ! -x "$CATEXE" ]
		then
			CATEXE="/bin/cat"
			if [ ! -x "$CATEXE" ]
			then
				echo "Unable to locate 'cat'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'ping' command
		#-----------------------------------------------------------------
		PINGEXE="/usr/bin/ping"
		if [ ! -x "$PINGEXE" ]
		then
			PINGEXE="/bin/ping"
			if [ ! -x "$PINGEXE" ]
			then
				echo "Unable to locate 'ping'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'sed' command
		#-----------------------------------------------------------------
		SEDEXE="/usr/bin/sed"
		if [ ! -x "$SEDEXE" ]
		then
			SEDEXE="/bin/sed"
			if [ ! -x "$SEDEXE" ]
			then
				echo "Unable to locate 'sed'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'grep' command
		#-----------------------------------------------------------------
		GREPEXE="/usr/bin/grep"
		if [ ! -x "$GREPEXE" ]
		then
			GREPEXE="/bin/grep"
			if [ ! -x "$GREPEXE" ]
			then
				echo "Unable to locate 'grep'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'rm' command
		#-----------------------------------------------------------------
		RMEXE="/usr/bin/rm"
		if [ ! -x "$RMEXE" ]
		then
			RMEXE="/bin/rm"
			if [ ! -x "$RMEXE" ]
			then
				echo "Unable to locate 'rm'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'sleep' command
		#-----------------------------------------------------------------
		SLEEPEXE="/usr/bin/sleep"
		if [ ! -x "$SLEEPEXE" ]
		then
			SLEEPEXE="/bin/sleep"
			if [ ! -x "$SLEEPEXE" ]
			then
				echo "Unable to locate 'sleep'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'awk' command
		#-----------------------------------------------------------------
		AWKEXE="/usr/bin/awk"
		if [ ! -x "$AWKEXE" ]
		then
			AWKEXE="/bin/awk"
			if [ ! -x "$AWKEXE" ]
			then
				echo "Unable to locate 'awk'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'mkdir' command
		#-----------------------------------------------------------------
		MKDIREXE="/usr/bin/mkdir"
		if [ ! -x "$MKDIREXE" ]
		then
			MKDIREXE="/bin/mkdir"
			if [ ! -x "$MKDIREXE" ]
			then
				echo "Unable to locate 'mkdir'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'cp' command
		#-----------------------------------------------------------------
		CPEXE="/usr/bin/cp"
		if [ ! -x "$CPEXE" ]
		then
			CPEXE="/bin/cp"
			if [ ! -x "$CPEXE" ]
			then
				echo "Unable to locate 'cp'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

                #-----------------------------------------------------------------
                # Resolve the location of the 'tar' command
                #-----------------------------------------------------------------
                TAREXE="/usr/bin/tar"
                if [ ! -x "$TAREXE" ]
                then
                        TAREXE="/bin/tar"
                        if [ ! -x "$TAREXE" ]
                        then
                                echo "Unable to locate 'tar'."
                                echo "Please report this message along with the location of the command on your system."
                                exit 1
                        fi
                fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'chmod' command
		#-----------------------------------------------------------------
		CHMODEXE="/usr/bin/chmod"
		if [ ! -x "$CHMODEXE" ]
		then
			CHMODEXE="/bin/chmod"
			if [ ! -x "$CHMODEXE" ]
			then
				echo "Unable to locate 'chmod'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'chown' command
		#-----------------------------------------------------------------
		CHOWNEXE="/usr/bin/chown"
		if [ ! -x "$CHOWNEXE" ]
		then
			CHOWNEXE="/bin/chown"
			if [ ! -x "$CHOWNEXE" ]
			then
				echo "Unable to locate 'chown'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'ln' command
		#-----------------------------------------------------------------
		LNEXE="/usr/bin/ln"
		if [ ! -x "$LNEXE" ]
		then
			LNEXE="/bin/ln"
			if [ ! -x "$LNEXE" ]
			then
				echo "Unable to locate 'ln'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'tr' command
		#-----------------------------------------------------------------
		TREXE="/usr/bin/tr"
		if [ ! -x "$TREXE" ]
		then
			TREXE="/bin/tr"
			if [ ! -x "$TREXE" ]
			then
				echo "Unable to locate 'tr'."
				echo "Please report this message along with the location of the command on your system."
				exit 1
			fi
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'chkconfig' command
		#-----------------------------------------------------------------
		CHKCONFIGEXE="/sbin/chkconfig"
		if [ ! -x "$CHKCONFIGEXE" ]
		then
			echo "Unable to locate 'chkconfig'."
			echo "Please report this message along with the location of the command on your system."
			exit 1
		fi

		CPUCHK=`$UNAMEEXE -i`
		CINAME=`$UNAMEEXE -n`

		#-----------------------------------------------------------------
		# Resolve the location of the 'pidof' command
		#-----------------------------------------------------------------
		PIDOFEXE="/sbin/pidof"
		if [ ! -x "$PIDOFEXE" ]
		then
			echo "Unable to locate 'pidof'."
			echo "Please report this message along with the location of the command on your system."
			exit 1
		fi

		#-----------------------------------------------------------------
		# Resolve the location of the 'service' command
		#-----------------------------------------------------------------
		SERVICEEXE="/sbin/service"
		if [ ! -x "$SERVICEEXE" ]
		then
			echo "Unable to locate 'service'."
			echo "Please report this message along with the location of the command on your system."
			exit 1
		fi
	}
	############################################################################################
	# Resolve the Operating System
	############################################################################################
	function resolve_OperatingSystem () {
		#-----------------------------------------------------------------
		# Resolve the OS
		#-----------------------------------------------------------------
		DIST_OS=`$UNAMEEXE -s | $TREXE [:upper:] [:lower:] | $TREXE -d [:blank:]`
		case "$DIST_OS" in
			'linux')
				if [ "$OSTYPE" = "linux" ]
				then
					# SLES, 
					DIST_OS="linux"
				else
					# RedHat, CentOS, Pear, Ubuntu, Mint, Peppermint
					DIST_OS="linux-gnu"
				fi

				OSCHK=`$CATEXE /etc/*-release`
				;;
			'sunos')
				DIST_OS="solaris"
				OSCHK="Solaris"
				;;
			'hp-ux' | 'hp-ux64')
				DIST_OS="hpux"
				OSCHK="HP-UX"
				;;
			'darwin')
				DIST_OS="macosx"
				PSKEYWORD="command"
				OSCHK="Mac OS-X"
				;;
			'unix_sv')
				DIST_OS="unixware"
				OSCHK="UNIX SV"
				;;
			'aix')
				DIST_OS="aix"
				OSCHK="AIX"
				;;
		esac
	}
	############################################################################################
	# Resolve the Architecture
	############################################################################################
	function resolve_Architecture () {
		#-----------------------------------------------------------------
		# Resolve the architecture
		#-----------------------------------------------------------------
		UNAME_PROC_OPTION="-m"
		if [ "$DIST_OS" = "aix" ]; then
			UNAME_PROC_OPTION="-p"
		fi

		PROC_ARCH=`$UNAMEEXE $UNAME_PROC_OPTION | $TREXE [:upper:] [:lower:] | $TREXE -d [:blank:]`

		while :
		do
			case "$PROC_ARCH" in
				'amd64' | 'athlon' | 'i386' | 'i486' | 'i586' | 'i686' | 'x86_64' | 'i86pc')
					DIST_ARCH="x86"
					break;;
				'ia32' | 'ia64')
					 DIST_ARCH="ia"
					break;;
				'ip27')
					DIST_ARCH="mips"
					break;;
				'power' | 'powerpc' | 'power_pc' | 'ppc64' | 'powermacintosh')
					DIST_ARCH="ppc"
					break;;
				'pa_risc' | 'pa-risc')
					DIST_ARCH="parisc"
					break;;
				'sun4u' | 'sun4v' | 'sparcv9' | 'sparc')
					DIST_ARCH="sparc"
					break;;
				'9000/800' | '9000/785')
					DIST_ARCH="parisc"
					break;;
				*)
					echo "Your machine's hardware type ($UNAMEEXE $UNAME_PROC_OPTION) = $PROC_ARCH was not recognized by the Service Wrapper as a supported platform."
					echo "Please report this message along with your machine's processor/architecture."
					exit 1
					;;
			esac
		done
	}
	############################################################################################
	# Install directory structure function
	############################################################################################
	function install_directories () {
		AGENTDIR="$BASEDIR/agent"
		MANAGERDIR="$BASEDIR/agent_manager"
		REDHAT_5_32_BINS="$CURDIR/firescope/agent/bins/RedHat_5_32_Dynamic"
		REDHAT_5_64_BINS="$CURDIR/firescope/agent/bins/RedHat_5_64_Dynamic"
		REDHAT_6_32_BINS="$CURDIR/firescope/agent/bins/RedHat_6_32_Dynamic"
		REDHAT_6_64_BINS="$CURDIR/firescope/agent/bins/RedHat_6_64_Dynamic"
		SLES10_32_BINS="$CURDIR/firescope/agent/bins/SLES_32_Dynamic"
		SLES10_64_BINS="$CURDIR/firescope/agent/bins/SLES_64_Dynamic"
		SLES11_32_BINS="$CURDIR/firescope/agent/bins/SLES_32_Dynamic"
		SLES11_64_BINS="$CURDIR/firescope/agent/bins/SLES_64_Dynamic"
		REDHAT_32_INIT="$CURDIR/etc/init.d/RedHat_32"
		REDHAT_64_INIT="$CURDIR/etc/init.d/RedHat_64"
		SLES10_32_INIT="$CURDIR/etc/init.d/SLES_32"
		SLES10_64_INIT="$CURDIR/etc/init.d/SLES_64"
		SLES11_32_INIT="$CURDIR/etc/init.d/SLES_32"
		SLES11_64_INIT="$CURDIR/etc/init.d/SLES_64"
		AGENT_PID_FILES="$CURDIR/firescope/agent/logs"
		AGENT_PID_DEST_FILES="$AGENTDIR/logs"
		JMX_INSTALL_FILES_DIR="$CURDIR/jmxdelegate"
		JMXDIR="$AGENTDIR/modules/jmxdelegate"
		CONFIGFILE="${AGENTDIR}/conf/firescope_agentd_posix.xml"
		CONFIGFILEBASE="${AGENTDIR}/conf"
		RELEASENOTESSOURCE="${CURDIR}/ReleaseNotes.txt"
		RELEASENOTESDEST="${AGENTDIR}/docs"
		SCRIPTSSOURCE="${CURDIR}/firescope/agent/scripts"
		SCRIPTSDEST="${AGENTDIR}/scripts"
	}
	############################################################################################
	# End - Agent init sed replace function
	############################################################################################

	############################################################################################
	# Start - sedreplace function 
	############################################################################################
	# Usage
	# sedreplace $1 $2 $3
	# $1 what to search for
	# $2 file to search in
	# $3 line offset in numbers
	# $4 what to replace with
	# e.g. sedreplace "AGENTDIR=AGENTDIR" "$INIT"/firescope_agentd 0 "AGENTDIR=$AGENTDIR"
	############################################################################################
	function sedreplace () {
		AIModeKey=`$GREPEXE "$1" "$2" -n | $CUTEXE -d : -f1`
		echo "AIModeKey=$AIModeKey"  >>$INSTALLERLOG
		let AIModeValue=$AIModeKey+"$3"
		echo "AIModeValue=$AIModeValue"  >>$INSTALLERLOG
		sedLine=`$SEDEXE $AIModeValue'q;d' $2`
		echo "sedLine=$sedLine"  >>$INSTALLERLOG
		sedLine1=`echo $sedLine` # | $CUTEXE -d '>' -f2 | $CUTEXE -d '<' -f1`
		echo "sedLine1=$sedLine1"  >>$INSTALLERLOG
		sedLine2="$4"
		echo "sedLine2=$sedLine2"  >>$INSTALLERLOG
		`$SEDEXE -i -e "$AIModeValue"'s;'"$sedLine1"';'"$sedLine2"';g' $2`
	}
	############################################################################################
	# End - sedreplace function
	############################################################################################
	############################################################################################
	# Agent init sed replace function
	############################################################################################
	agent_init_sed () {
		echo "****************************Agent init set agent path 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "AGENTDIR=AGENTDIR" "$INIT"/firescope_agentd 0 "AGENTDIR=$AGENTDIR"
		echo "****************************Agent init set config path 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "agentd_cfgfile=agentd_cfgfile" "$INIT/firescope_agentd" 0 "agentd_cfgfile=$CONFIGFILE"
		echo "****************************Agent init set pid path 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "PIDFILE=PIDFILE" "$INIT/firescope_agentd" 0 "PIDFILE=$AGENTDIR/logs/firescope_agentd.pid"
		echo "****************************Agent init command 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "FSUSER=FSUSER" "$INIT/firescope_agentd" 0 "FSUSER=$FSUSER"
		echo "****************************Agent init command 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "firescope_agentd=firescope_agentd" "$INIT/firescope_agentd" 0 "firescope_agentd=$AGENTDIR/bin/firescope_agentd"
	}
	############################################################################################
	# End - Agent init sed replace function
	############################################################################################
	############################################################################################
	# Agent Manager init sed replace function 
	############################################################################################
	agent_manager_init_sed () {
		echo "****************************Agent manager init set agent path 'Agent Manager init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "MANAGERDIR=MANAGERDIR" "$INIT/firescope_agent_managerd" 0 "MANAGERDIR=$MANAGERDIR"
		echo "****************************Agent manager init set config path 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "agentd_cfgfile=agentd_cfgfile" "$INIT/firescope_agent_managerd" 0 "agentd_cfgfile=$CONFIGFILE"
		echo "****************************Agent manager init set pid path 'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "PIDFILE=PIDFILE" "$INIT/firescope_agent_managerd" 0 "PIDFILE=$AGENTDIR/logs/firescope_agentd_managerd.pid}"
		echo "****************************Agent manager init set FSMUSER  'Agent init sed replace function'***************************" >>$INSTALLERLOG
			sedreplace "FSMUSER=FSMUSER" "$INIT/firescope_agent_managerd" 0 "FSMUSER=$FSMUSER"
		echo "****************************Agent manager init set manager path 'Agent init sed replace function'***********************" >>$INSTALLERLOG
			sedreplace "firescope_agent_managerd=firescope_agent_managerd" "$INIT/firescope_agent_managerd" 0 "firescope_agent_managerd=\${firescope_AGENT_MANAGERD-$MANAGERDIR/firescope_agent_managerd -c \$agentd_cfgfile}"
	}
	############################################################################################
	# End - Agent Manager init sed replace function
	############################################################################################
####################################################################################################
# copycorefiles function start
####################################################################################################
# Usage
# copycorefiles $1 $2
# $1 OS Bins (i.e. $REDHAT_5_32_BINS, $REDHAT_5_64_BINS, ...)
# $2 INIT Files (i.e. $REDHAT_32_INIT, $REDHAT_64_INIT, ...)
# e.g. copycorefiles
####################################################################################################
function copycorefiles () {
		#------------------------------------------------------------------------------------
		# Copy agent files
		#------------------------------------------------------------------------------------
		echo "Copying $1 Agent bin" >>$INSTALLERLOG
		`$CPEXE $1/firescope_agentd $AGENTDIR/bin/firescope_agentd >>$INSTALLERLOG`
		`$CPEXE $1/libstdc++.so.6 $AGENTDIR/lib/libstdc++.so.6 >>$INSTALLERLOG`
		`$CPEXE $RELEASENOTESSOURCE $RELEASENOTESDEST >>$INSTALLERLOG`
		`$CPEXE $SCRIPTSSOURCE/oracle.tar $SCRIPTSDEST/oracle.tar >>$INSTALLERLOG`
        `$TAREXE -xf $SCRIPTSSOURCE/oracle.tar -C $SCRIPTSDEST >>$INSTALLERLOG`
		`$CHMODEXE +x $SCRIPTSDEST/oracle/cont.sql >>$INSTALLERLOG`
		`$CHMODEXE +x $SCRIPTSDEST/oracle/fireorav3 >>$INSTALLERLOG`
		`$CHMODEXE +x $SCRIPTSDEST/oracle/login.sql >>$INSTALLERLOG`
		`$CHMODEXE +x $SCRIPTSDEST/oracle/oraenv >>$INSTALLERLOG`
		`$CPEXE $SCRIPTSSOURCE/get_system_info.sh $SCRIPTSDEST/ >>$INSTALLERLOG`
		`$CHMODEXE +x $SCRIPTSDEST/get_system_info.sh >>$INSTALLERLOG`
		`$CPEXE $AGENT_PID_FILES/firescope_agentd.pid $AGENT_PID_DEST_FILES/ >>$INSTALLERLOG`
		#------------------------------------------------------------------------------------
		# Copy agent manager files
		#------------------------------------------------------------------------------------
		if [ "$SKIPAGENTMANAGER" != "1" ]; then
			echo "Copying $1 Agent Manager bins" >>$INSTALLERLOG
			`$CPEXE $AGENT_PID_FILES/firescope_agent_managerd.pid $AGENT_PID_DEST_FILES/ >>$INSTALLERLOG`
			`$CPEXE $1/firescope_agent_managerd $MANAGERDIR`
			`$CPEXE $1/minizip $MANAGERDIR`
			`$CPEXE $1/miniunzip $MANAGERDIR`
		else
			echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped upgrading manager" >>$INSTALLERLOG
		fi
		#------------------------------------------------------------------------------------
		# Copy agent init files
		#------------------------------------------------------------------------------------
		`$CPEXE $2/firescope_agentd $INIT >>$INSTALLERLOG`
		if [ "$SKIPAGENTMANAGER" != "1" ]; then
			`$CPEXE $2/firescope_agent_managerd $INIT >>$INSTALLERLOG`
		else
			echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skippedcopy init manager" >>$INSTALLERLOG
		fi
		#------------------------------------------------------------------------------------
		# Chmod agent init files
		#------------------------------------------------------------------------------------
		`$CHMODEXE +x $INIT/firescope_agentd >>$INSTALLERLOG`
		if [ "$SKIPAGENTMANAGER" != "1" ]; then
			`$CHMODEXE +x $INIT/firescope_agent_managerd >>$INSTALLERLOG`
		else
			echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped chmod manager" >>$INSTALLERLOG
		fi
}
	#############################################################################################
	# End - copycorefiles function
	#############################################################################################
	#############################################################################################
	# init_on_boot function
	#############################################################################################
function init_on_boot () {
	echo "CPU Check = $CPUCHK" >>$INSTALLERLOG
	echo "Operating System Check = $OSCHK" >>$INSTALLERLOG
	#------------------------------------------------------------------------------------
	# Available Runlevels (RHEL)
	#------------------------------------------------------------------------------------
	# Runlevel		Description
	#------------------------------------------------------------------------------------
	#   0			   Halt
	#   1			   Single-User mode
	#   2			   Multi-user mode console logins only (without networking)
	#  *3			   Multi-User mode, console logins only
	#   4			   Not used/User-definable
	#  *5			   Multi-User mode, with display manager as well as console logins (X11)
	#   6			   Reboot
	#------------------------------------------------------------------------------------
	if [ `echo $OSCHK | $GREPEXE -i -c -m1 "Red Hat Enterprise Linux\|CentOS\|Ubuntu"` == "1" ]; then 
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/rc0.d/K06firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/rc0.d/S91firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/rc1.d/K06firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/rc1.d/S91firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/rc2.d/K06firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/rc2.d/S91firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/rc3.d/K06firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/rc3.d/S91firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/rc4.d/K06firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/rc4.d/S91firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/rc5.d/K06firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/rc5.d/S91firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/rc6.d/K06firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/rc6.d/S91firescope_agentd`

			if [ "$SKIPAGENTMANAGER" != "1" ]; then
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/rc0.d/K06firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/rc0.d/S91firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/rc1.d/K06firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/rc1.d/S91firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/rc2.d/K06firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/rc2.d/S91firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/rc3.d/K06firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/rc3.d/S91firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/rc4.d/K06firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/rc4.d/S91firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/rc5.d/K06firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/rc5.d/S91firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/rc6.d/K06firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/rc6.d/S91firescope_agent_managerd`
			else
				echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped run levels manager" >>$INSTALLERLOG
			fi
	#------------------------------------------------------------------------------------
	# Available Runlevels (SLES)
	#------------------------------------------------------------------------------------
	# Runlevel		Description
	#------------------------------------------------------------------------------------
	#   0			   Halt
	#   1			   Single-User mode
	#   2			   Multi-User mode without networking
	#  *3			   Multi-User mode, console logins only
	#   4			   Not used/User-definable
	#  *5			   Multi-User mode with display manager
	#   6			   Reboot
	#   S			   Single-User Mode[6]
	#------------------------------------------------------------------------------------
	elif [ `echo $OSCHK | $GREPEXE -i -c -m1 "SUSE Linux Enterprise Server 10\|SUSE Linux Enterprise Server 11"` == "1" ]; then 
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/init.d/rc0.d/K06firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/init.d/rc0.d/S91firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/init.d/rc1.d/K06firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/init.d/rc1.d/S91firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/init.d/rc2.d/K06firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/init.d/rc2.d/S91firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/init.d/rc3.d/K06firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/init.d/rc3.d/S91firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/init.d/rc4.d/K06firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/init.d/rc4.d/S91firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/init.d/rc5.d/K06firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/init.d/rc5.d/S91firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/init.d/rc6.d/K06firescope_agentd`
		`$LNEXE -sf /etc/init.d/firescope_agentd /etc/init.d/rc6.d/S91firescope_agentd`
		insserv firescope_agentd -n

			if [ "$SKIPAGENTMANAGER" != "1" ]; then
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/init.d/rc0.d/K06firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/init.d/rc0.d/S91firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/init.d/rc1.d/K06firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/init.d/rc1.d/S91firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/init.d/rc2.d/K06firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/init.d/rc2.d/S91firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/init.d/rc3.d/K06firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/init.d/rc3.d/S91firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/init.d/rc4.d/K06firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/init.d/rc4.d/S91firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/init.d/rc5.d/K06firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/init.d/rc5.d/S91firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/init.d/rc6.d/K06firescope_agent_managerd`
				`$LNEXE -sf /etc/init.d/firescope_agent_managerd /etc/init.d/rc6.d/S91firescope_agent_managerd`
				insserv firescope_agent_managerd -n
			else
				echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped run levels manager" >>$INSTALLERLOG
			fi
	fi
}
	############################################################################################
	# End - init_on_boot function
	############################################################################################
	############################################################################################
	# checkos function start
	############################################################################################
	# Usage
	# checkos
	# e.g. checkos
	############################################################################################
function checkos () {
	echo "CPU Check = $CPUCHK" >>$INSTALLERLOG
	echo "Operating System Check = $OSCHK" >>$INSTALLERLOG
	`$SLEEPEXE 1`
	
	if [ $CPUCHK == "x86_64" ]; then 
		if [ `echo $OSCHK | $GREPEXE -i -c -m1 "Red Hat Enterprise Linux\|Ubuntu"` == "1" ]; then 
			if [ `echo $OSCHK | $GREPEXE -i -c -m1 "release 6"` == "1" ]; then 
				OSNAME=`$CATEXE /etc/*-release | $GREPEXE -i -m1 "Red Hat Enterprise Linux"` >>$INSTALLERLOG
				COPYFROM=$REDHAT_6_64_BINS
				COPYTO=$REDHAT_64_INIT
			else
				OSNAME=`$CATEXE /etc/*-release | $GREPEXE -i -m1 "Red Hat Enterprise Linux"` >>$INSTALLERLOG
				COPYFROM=$REDHAT_5_64_BINS
				COPYTO=$REDHAT_64_INIT
			fi
		elif [ `echo $OSCHK | $GREPEXE -i -c -m1 "SUSE Linux Enterprise Server 10"` == "1" ]; then 
				OSNAME=`$CATEXE /etc/*-release | $GREPEXE -i -m1 "SUSE Linux Enterprise Server 10"` >>$INSTALLERLOG
				COPYFROM=$SLES10_64_BINS
				COPYTO=$SLES10_64_INIT
		elif [ `echo $OSCHK | $GREPEXE -i -c -m1 "SUSE Linux Enterprise Server 11"` == "1" ]; then 
				OSNAME=`$CATEXE /etc/*-release | $GREPEXE -i -m1 "SUSE Linux Enterprise Server 11"` >>$INSTALLERLOG
				COPYFROM=$SLES11_64_BINS
				COPYTO=$SLES11_64_INIT
		elif [ `echo $OSCHK | $GREPEXE -i -c -m1 "CentOS"` == "1" ]; then 
				OSNAME=`$CATEXE /etc/*-release | $GREPEXE -i -m1 "CentOS"` >>$INSTALLERLOG
				COPYFROM=$REDHAT_5_64_BINS
				COPYTO=$REDHAT_64_INIT
		else
			echo "Unsupported OS $OSCHK" >>$INSTALLERLOG
			echo "Unsupported OS $OSCHK"
			exit
		fi
	elif [ $CPUCHK == "i386" ]; then 
	   if [ `echo $OSCHK | $GREPEXE -i -c -m1 "Red Hat Enterprise Linux\|Ubuntu"` == "1" ]; then 
	   	   if [ `echo $OSCHK | $GREPEXE -i -c -m1 "release 6"` == "1" ]; then 
				OSNAME=`$CATEXE /etc/*-release | $GREPEXE -i -m1 "Red Hat Enterprise Linux"` >>$INSTALLERLOG
				COPYFROM=$REDHAT_6_32_BINS
				COPYTO=$REDHAT_32_INIT
		   else
				OSNAME=`$CATEXE /etc/*-release | $GREPEXE -i -m1 "Red Hat Enterprise Linux"` >>$INSTALLERLOG
				COPYFROM=$REDHAT_5_32_BINS
				COPYTO=$REDHAT_32_INIT
		   fi
	   elif [ `echo $OSCHK | $GREPEXE -i -c -m1 "SUSE Linux Enterprise Server 10"` == "1" ]; then 
				OSNAME=`$CATEXE /etc/*-release | $GREPEXE -i -m1 "SUSE Linux Enterprise Server 10"` >>$INSTALLERLOG
				COPYFROM=$SLES10_32_BINS
				COPYTO=$SLES10_32_INIT
	   elif [ `echo $OSCHK | $GREPEXE -i -c -m1 "SUSE Linux Enterprise Server 11"` == "1" ]; then 
				OSNAME=`$CATEXE /etc/*-release | $GREPEXE -i -m1 "SUSE Linux Enterprise Server 11"` >>$INSTALLERLOG
				COPYFROM=$SLES11_32_BINS
				COPYTO=$SLES11_32_INIT
	   elif [ `echo $OSCHK | $GREPEXE -i -c -m1 "CentOS"` == "1" ]; then 
				OSNAME=`$CATEXE /etc/*-release | $GREPEXE -i -m1 "CentOS"` >>$INSTALLERLOG
				COPYFROM=$REDHAT_5_32_BINS
				COPYTO=$REDHAT_32_INIT
	   else
			echo "Unsupported OS $OSCHK" >>$INSTALLERLOG
			echo "Unsupported OS $OSCHK"
			exit
	   fi
	else
		echo "Unsupported CPU $CPUCHK" >>$INSTALLERLOG
		echo "Unsupported CPU $CPUCHK"
		exit
   fi
}
	############################################################################################
	# End - checkos function
	############################################################################################
	############################################################################################
	# Uninstaller sed replace function
	############################################################################################
	uninstaller_sed () {
	echo "****************************Agent uninstall dir. 'Uninstaller sed replace function '***************************" >>$INSTALLERLOG
		sedreplace "INIT=INIT" "$AGENTDIR/FireScope_Agent_Uninstall.sh" 0 "INIT=$INIT"
		sedreplace "INSTALLDIR=INSTALLDIR" "$AGENTDIR/FireScope_Agent_Uninstall.sh" 0 "INSTALLDIR=$BASEDIR"
	}
	############################################################################################
	# End - Uninstaller sed replace function
	############################################################################################
	############################################################################################
	# Check Config function
	############################################################################################
	# Usage
	# check_configuration $1 $2 $3
	# $1 Component name (i.e. firescope_agentd, firescope_agent_managerd, ...)
	# $2 Run Level check (i.e. 3, 5,..)
	# e.g. check_configuration firescope_agentd 3
	############################################################################################
	check_configuration () {
		echo "****************************Check Config function $1:$2 '***************************" >>$INSTALLERLOG
			IS_CHKCONFIG=`$CHKCONFIGEXE --list | $GREPEXE $1 | $CUTEXE -f$2 | $CUTEXE -d ":" -f2`

				if [ "$IS_CHKCONFIG" == "on" ];
				then
						echo "$1 $2 is ON:$IS_CHKCONFIG" >>$INSTALLERLOG
						echo "****************************Check Config function $1:$3 '***************************" >>$INSTALLERLOG
						IS_CHKCONFIG=`chkconfig --list | $GREPEXE $1 | $CUTEXE -f$3 | $CUTEXE -d ":" -f2`

						if [ "$IS_CHKCONFIG" == "on" ];
						then
								echo "$1 $3 is ON:$IS_CHKCONFIG" >>$INSTALLERLOG
						else
								echo "$1 NOT installed $IS_CHKCONFIG" >>$INSTALLERLOG
								IS_CHKCONFIG=""
						fi
				else
						echo "$1 NOT installed $IS_CHKCONFIG" >>$INSTALLERLOG
						IS_CHKCONFIG=""
				fi
	}
	########################################################################################
	# End - Check Config function
	########################################################################################
################################################################################################
# End - functions
################################################################################################

	resolve_Executables
	resolve_OperatingSystem
	resolve_Architecture

if [ -f "$INSTALLERLOG" ]; then
	`$RMEXE -f $INSTALLERLOG`
fi
###########################
# FireScope Agent Getopts settings
###########################
install_directories
f="0"
JavaMinOptCalled="0"
JavaMaxOptCalled="0"
while getopts ":A:a:b:c:d:f:H:J:j:K:k:m:n:p:s:t:V:huZ" o
do case $o in
	###########################
	# FireScope Server Set Info
	###########################
	A)
		f="1"
		echo "Checking for connectivity to the FireScope Appliance."
		echo "$DATE == $WHOAMI Passed1FireScopeServerIP=$OPTARG"  >>$INSTALLERLOG

#		if [[ "$OPTARG" =~ "^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])(\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])){3}$" ]]; then
		if [ "$OPTARG" != "" ]; then
			SERVERCHECK=`$PINGEXE -c 3 $OPTARG | $GREPEXE -c "3 received"`
			echo "$DATE == $WHOAMI Server $PINGEXE Check = ${SERVERCHECK}"  >>$INSTALLERLOG
			echo "Checking for route to Appliance. Please standby."
			if [ ${SERVERCHECK} != "1" ]; then
				echo "Could not $PINGEXE the FireScope Server!!! Please check IP or DNS and try again."  >>$INSTALLERLOG
			fi
		else
			echo "Invalid IP address, please provide the FireScope appliance IP address."
			echo "$Installer -h more help."
			exit 1
		fi
		SERVER="$OPTARG"
		echo "$DATE == $WHOAMI Set1FireScopeServerIP=${SERVER}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Server Port
	###########################
	a)
		echo "$DATE == $WHOAMI PassedServerPort=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
			SPORT="$OPTARG"
		else
			echo "Server Port (-a) must be between 1 and 65535!!!"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetServerPort=${SPORT}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Path
	###########################
	b)
		echo "$DATE == $WHOAMI Passed2InstallPath=$OPTARG"  >>$INSTALLERLOG
		if [ "$OPTARG" = "" ]; then
			BASEDIR="/opt/firescope"
		elif [ "$OPTARG" != "" ]; then
			BASEDIR="$OPTARG"
			install_directories
		fi
		echo "$DATE == $WHOAMI Set2InstallPath=${BASEDIR}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Port
	###########################
	p)
		echo "$DATE == $WHOAMI Passed3Port=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
			APORT="$OPTARG"
		else
			echo "Agent Port (-p) must be between 1 and 65535!!!"
			exit 1
		fi
		echo "$DATE == $WHOAMI Set3Port=${APORT}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Manager Port
	###########################
	m)
		echo "$DATE == $WHOAMI PassedManPort=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
			MPORT="$OPTARG"
		else
			echo "Agent Manager Port (-m) must be between 1 and 65535!!!"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetManPort=${MPORT}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Remote Commands
	###########################
	c)
		echo "$DATE == $WHOAMI PassedRMTCMD=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0|1]$" ]]; then
			RMTCMD="$OPTARG"
		else
			RMTCMD="0"
			echo "Invalid Argument for Remote commands (-c)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetRMTCMD=${RMTCMD}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Disable Active checks
	###########################
	d)
		echo "$DATE == $WHOAMI PassedDActive=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0|1]$" ]]; then
			DACTIVE="$OPTARG"
		else
			DACTIVE="0"
			echo "Invalid argument for Disable Active Checks (-d)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetDActive=${DACTIVE}"  >>$INSTALLERLOG
	;;
	###########################
	# Run as firescop user
	###########################
	f)
		echo "$DATE == $WHOAMI PassedRunAsFireScop=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0|1]$" ]]; then
			RUNASFIRESCOP="$OPTARG"
		else
			RUNASFIRESCOP="0"
			echo "Invalid argument for RunAsFireScop (-f)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetRunAsFireScop=${RUNASFIRESCOP}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent JMX Enable check
	###########################
	J)
		echo "$DATE == $WHOAMI PassedJMX=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0|1]$" ]]; then
			JMX="$OPTARG"
		else
			echo "Invalid argument for JMX Enable (-J)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetJMX=$JMX"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent JMX PORT
	###########################
	j)
		echo "$DATE == $WHOAMI PassedJMXPort=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "0" ] && [ "$OPTARG" -lt "65536" ]; then
			JPORT="$OPTARG"
		else
			echo "JMX Port (-j) must be between 1 and 65535!!!"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetJMXPort=${JPORT}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Java Heap Memory MAX
	###########################
	K)
		 JavaMaxOptCalled="1"
		echo "$DATE == $WHOAMI PassedJavaMemMax=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "[^a-zA-Z]\{1,\}" ]] && [ "$OPTARG" -gt "0" ]; then
			JAVAMAX="$OPTARG"
		else
			JAVAMAX="8"
		fi
		echo "$DATE == $WHOAMI SetJavaMemMax=${JAVAMAX}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Java Heap Memory MIN
	###########################
	k)
		JavaMinOptCalled="1"
		echo "$DATE == $WHOAMI PassedJavaMemMin=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "[^a-zA-Z]\{1,\}" ]] && [ "$OPTARG" -gt "0" ]; then
			JAVAMIN="$OPTARG"
		else
			JAVAMIN="6"
		fi
		echo "$DATE == $WHOAMI SetJavaMemMin=${JAVAMIN}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Hostname
	###########################
	H)
		echo "$DATE == $WHOAMI PassedCINAME=$OPTARG"  >>$INSTALLERLOG
		if [ "$OPTARG" = "" ]; then
			CINAME=`hostname -s`
		fi
		if [ "$OPTARG" != "" ]; then
			CINAME="$OPTARG"
		fi
		echo "$DATE == $WHOAMI SetCINAME=${CINAME}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Realtime
	###########################
	s)
		echo "$DATE == $WHOAMI PassedREALTIME=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0|1]$" ]]; then
			REALTIME="$OPTARG"
		else
			echo "Invaild argument for Agent Realtime mode (-s)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetREALTIME=${REALTIME}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Storetime
	###########################
	t)
		echo "$DATE == $WHOAMI PassedSTORETIME=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "29" ] && [ "$OPTARG" -lt "601" ]; then
			STORETIME="$OPTARG"
		else
			echo "Invaild value for Store and Forward time (-t)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetSTORETIME=${STORETIME}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent upgrade
	###########################
	u)
		UPGRADE="1"
	;;
	###########################
	# Java Path check
	###########################
	V)
		echo "$DATE == $WHOAMI PassedJVM=$OPTARG"  >>$INSTALLERLOG
		if [ "$OPTARG" = "" ]; then
			JVM=$JAVAPATH
		fi
		if [ "$OPTARG" != "" ]; then
			JVM="$OPTARG"
		fi
		echo "$DATE == $WHOAMI SetJVM=${STORETIME}"  >>$INSTALLERLOG
	;;
	###########################
	# FireScope Agent Storecount
	###########################
	n)
		echo "$DATE == $WHOAMI PassedSTORECOUNT=$OPTARG"  >>$INSTALLERLOG
		if [[ "$OPTARG" =~ "^[0-9]+$" ]] && [ "$OPTARG" -gt "9" ] && [ "$OPTARG" -lt "201" ]; then
			STORECOUNT="$OPTARG"
		else
			echo "Invalid value for Store and Forward Count (-n)"
			exit 1
		fi
		echo "$DATE == $WHOAMI SetSTORECOUNT=${STORECOUNT}"  >>$INSTALLERLOG
	;;
	h)
		show_help; exit 0
	;;
	Z)
		SKIPAGENTMANAGER="1"
	;;
	\?)
		echo "Invalid option: -$OPTARG"
		echo "$Installer -h for more help."
		exit 1
	;;
	:)
		echo "Option -$OPTARG requires an argument."
		echo "$Installer -h for more help."
		exit 1
	;;
	esac
done

###########################
# FireScope Check for required flags
###########################
	if [ $UPGRADE -ne "1" ]; then
		if [ "$f" = "0" ]; then 
			echo "The flag -A is required
			$INSTALLER -h for more help"
			exit 1
		elif [ "$1" == "-h" ]; then
			show_help
		elif [ "$1" == "--help" ]; then
			show_help
			exit 0
		fi
	fi
####################################################################################################
#Check if user is root
####################################################################################################
	if [ "${WHOAMI}" != "root" ]; then
		echo "Sorry, root required to install agent."
		exit 1
	fi
####################################################################################################
#End Check if user is root
####################################################################################################
echo -e "\033[40m\033[40;33m" #sets back gound to black
####################################################################################################
#checks if there is a service account on system
####################################################################################################
	#################################
	#Begin Check
	#################################
		#Required Variables
		#################################
		# FSUSER
		# FSGROUP
		#################################
	checkos
	echo "Service account check for Agent" 2>&1 >>$INSTALLERLOG
	IDTEST="`$IDEXE -un $FSUSER  2>>$INSTALLERLOG`"
	echo "IDTEST=$IDTEST" 2>&1 >>$INSTALLERLOG
	GRPTEST="`$CATEXE /etc/group | $GREPEXE -woz $FSGROUP: | $GREPEXE -wo $FSGROUP  2>>$INSTALLERLOG`"
	echo "GRPTEST=$GRPTEST"  2>&1 >>$INSTALLERLOG
	COUNTER=0
	if [ -z "$IDTEST" ]; then
		echo "Creating Service Account: $FSUSER"  2>&1 >>$INSTALLERLOG
		`useradd -Mr $FSUSER 2>&1 >>$INSTALLERLOG`
		echo "`$IDEXE $FSUSER  &>$INSTALLERLOG`" 
		if [ -z "$GRPTEST" ]; then
			echo "Creating Service Group: $FSGROUP"  2>&1 >>$INSTALLERLOG
			`groupadd -r $FSGROUP 2>>$INSTALLERLOG`
		fi
	else
		echo "User and Groups exist, Upgrading Agent Installation...."  2>&1 >>$INSTALLERLOG
	fi
	GRPTEST3="`$CATEXE /etc/group | $GREPEXE -woz oinstall: | $GREPEXE -wo oinstall  2>>$INSTALLERLOG`"
	echo "GRPTEST3=$GRPTEST3"  2>&1 >>$INSTALLERLOG
	if [ -n "$GRPTEST3" ]; then
		`usermod -a -G oinstall $FSUSER 2>&1 >>$INSTALLERLOG` 
	fi
	GRPTEST4="`$CATEXE /etc/group | $GREPEXE -woz dba: | $GREPEXE -wo dba  2>>$INSTALLERLOG`"
	echo "GRPTEST4=$GRPTEST4"  2>&1 >>$INSTALLERLOG
	if [ -n "$GRPTEST4" ]; then
		`usermod -a -G dba $FSUSER 2>&1 >>$INSTALLERLOG` 
	fi
	export LD_LIBRARY_PATH=$COPYFROM/:$LD_LIBRARY_PATH
####################################################################################################
#checks if there is a service account for Agent Manager on system
####################################################################################################
	#Begin Check
	#################################
		#Required Variables
		#################################
		# USER
		# GROUP
		#################################
	echo "Service account check for Agent Manager" >>$INSTALLERLOG
	IDTEST2="`$IDEXE -un $FSMUSER 2>>$INSTALLERLOG`"
	echo "IDTEST2=$IDTEST2" >>$INSTALLERLOG
	GRPTEST2="`$CATEXE /etc/group | $GREPEXE -woz $FSMGROUP: | $GREPEXE -wo $FSMGROUP 2>>$INSTALLERLOG`"
	echo "GRPTEST2=$GRPTEST2" 2>&1 >>$INSTALLERLOG
	COUNTER=0
	if [ -z "$IDTEST2" ]; then
		echo "Creating Service Account: $FSUSER"  2>&1 >>$INSTALLERLOG
		`useradd -Mr $FSMUSER 2>>$INSTALLERLOG`
		echo "`$IDEXE $FSMUSER 2>&1 >>$INSTALLERLOG`"
		if [ -z "$GRPTEST2" ]; then
			echo "Creating Service Group: $FSMGROUP"  2>&1 >>$INSTALLERLOG
			`groupadd -r $FSMGROUP 2>&1 >>$INSTALLERLOG`
		fi
	fi
####################################################################################################
# Service running checks
####################################################################################################
	AGENTSERVICE=`$PIDOFEXE firescope_agentd` 2>&1 >>$INSTALLERLOG
	if [ "$AGENTSERVICE" != "" ]; then
		`$SERVICEEXE firescope_agentd stop  2>&1 >>$INSTALLERLOG`
		echo "sent $SERVICEEXE stop for Agent"  2>&1 >>$INSTALLERLOG
		echo "pid = $AGENTSERVICE"  2>&1 >>$INSTALLERLOG
	else 
		AGENTSERVICE=`$PSEXE -aef | $GREPEXE $AGENTDIR/bin/firescope_agentd | $GREPEXE -v $GREPEXE | $GREPEXE -v start | $AWKEXE '{print $2}'` >>$INSTALLERLOG
		if [ "$AGENTSERVICE" != "" ]; then
			`$SERVICEEXE firescope_agentd stop  2>&1 >>$INSTALLERLOG`
			echo "sent $SERVICEEXE stop for Agent"  2>&1 >>$INSTALLERLOG
			echo "pid = $AGENTSERVICE"  2>&1 >>$INSTALLERLOG
		else
			echo "Agent was not running, Installing!"  2>&1 >>$INSTALLERLOG
		fi
	fi

	if [ "$SKIPAGENTMANAGER" != "1" ]; then
		AGENTMANAGERSERVICE=`$PIDOFEXE firescope_agent_managerd` 2>&1 >>$INSTALLERLOG
		if [ "$AGENTMANAGERSERVICE" != "" ]; then
			`$SERVICEEXE firescope_agent_managerd stop  2>&1 >>$INSTALLERLOG`
			echo "sent $SERVICEEXE stop for Agent Manager"  2>&1 >>$INSTALLERLOG
			echo "pid = $AGENTMANAGERSERVICE" 2>&1 >>$INSTALLERLOG
		else  
			AGENTMANAGERSERVICE=`$PSEXE -aef | $GREPEXE $MANAGERDIR/firescope_agent_managerd | $GREPEXE -v $GREPEXE | $GREPEXE -v start | $AWKEXE '{print $2}'` >>$INSTALLERLOG
			if [ "$AGENTMANAGERSERVICE" != "" ]; then
				`$SERVICEEXE firescope_agent_managerd stop  2>&1 >>$INSTALLERLOG`
				echo "sent $SERVICEEXE stop for Agent Manager"  2>&1 >>$INSTALLERLOG
				echo "pid = $AGENTMANAGERSERVICE" 2>&1 >>$INSTALLERLOG
			else
				echo "Agent Manager was not running, Installing" 2>&1 >>$INSTALLERLOG
			fi
		fi
	fi
####################################################################################################
################################
#End Check
################################
	echo "creating dir structure" >>$INSTALLERLOG
	`$MKDIREXE  -p $BASEDIR >>$INSTALLERLOG`
	`$MKDIREXE  -p $AGENTDIR >>$INSTALLERLOG`
	`$MKDIREXE  -p $AGENTDIR/bin >>$INSTALLERLOG`
	`$MKDIREXE  -p $AGENTDIR/lib >>$INSTALLERLOG`
	`$MKDIREXE  -p $AGENTDIR/.agent >>$INSTALLERLOG`
	`$MKDIREXE  -p $AGENTDIR/cache >>$INSTALLERLOG`
	`$MKDIREXE  -p $AGENTDIR/conf >>$INSTALLERLOG`
	`$MKDIREXE  -p $AGENTDIR/logs >>$INSTALLERLOG`
	`$MKDIREXE  -p $AGENTDIR/modules >>$INSTALLERLOG`
	`$MKDIREXE  -p $AGENTDIR/modules/jmxdelegate >>$INSTALLERLOG`
	`$MKDIREXE  -p $AGENTDIR/modules/jmxdelegate/jar >>$INSTALLERLOG`
	`$MKDIREXE  -p $AGENTDIR/scripts >>$INSTALLERLOG`
	`$MKDIREXE  -p $AGENTDIR/backup >>$INSTALLERLOG`
	if [ "$SKIPAGENTMANAGER" != "1" ]; then	
		`$MKDIREXE  -p $MANAGERDIR >>$INSTALLERLOG`
		`$MKDIREXE  -p $MANAGERDIR/.agent_manager >>$INSTALLERLOG`
		`$MKDIREXE  -p $MANAGERDIR/temp >>$INSTALLERLOG`
	else
		echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped $MKDIREXE  of manager" >>$INSTALLERLOG
	fi

################################
# Echo to $INSTALLERLOG
################################

	echo "$DATE == $WHOAMI $MKDIREXE  Variables" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI BASEDIR=$BASEDIR" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR=$AGENTDIR" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/bin-$AGENTDIR/bin" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/.agent=$AGENTDIR/.agent" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/cache=$AGENTDIR/cache" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/conf=$AGENTDIR/conf" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/logs=$AGENTDIR/logs" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/modules=$AGENTDIR/modules" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/modules/jmxdelegate=$AGENTDIR/modules/jmxdelegate" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/modules/jmxdelegate/jar=$AGENTDIR/modules/jmxdelegate/jar" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/scripts=$AGENTDIR/scripts" >>$INSTALLERLOG
	echo "$DATE == $WHOAMI AGENTDIR/backup=$AGENTDIR/backup" >>$INSTALLERLOG
	if [ "$SKIPAGENTMANAGER" != "1" ]; then	
		echo "$DATE == $WHOAMI MANAGERDIR=$MANAGERDIR" >>$INSTALLERLOG
		echo "$DATE == $WHOAMI MANAGERDIR/.agent_manager=$MANAGERDIR/.agent_manager" >>$INSTALLERLOG
		echo "$DATE == $WHOAMI MANAGERDIR/temp=$MANAGERDIR/temp" >>$INSTALLERLOG
	else
		echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped echo of manager" >>$INSTALLERLOG
	fi

################################
# Echo to $MANAGERDIR/.agent_manager/agent_paths
################################

	echo "$DATE == $WHOAMI $MKDIREXE  Variables" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI BASEDIR=$BASEDIR" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR=$AGENTDIR" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/bin-$AGENTDIR/bin" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/.agent=$AGENTDIR/.agent" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/cache=$AGENTDIR/cache" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/conf=$AGENTDIR/conf" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/logs=$AGENTDIR/logs" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/modules=$AGENTDIR/modules" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/modules/jmxdelegate=$AGENTDIR/modules/jmxdelegate" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/modules/jmxdelegate/jar=$AGENTDIR/modules/jmxdelegate/jar" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/scripts=$AGENTDIR/scripts" >>$MANAGERDIR/.agent_manager/agent_paths
	echo "$DATE == $WHOAMI AGENTDIR/backup=$AGENTDIR/backup" >>$MANAGERDIR/.agent_manager/agent_paths
	if [ "$SKIPAGENTMANAGER" != "1" ]; then	
		echo "$DATE == $WHOAMI MANAGERDIR=$MANAGERDIR" >>$MANAGERDIR/.agent_manager/agent_paths
		echo "$DATE == $WHOAMI MANAGERDIR/.agent_manager=$MANAGERDIR/.agent_manager" >>$MANAGERDIR/.agent_manager/agent_paths
		echo "$DATE == $WHOAMI MANAGERDIR/temp=$MANAGERDIR/temp" >>$MANAGERDIR/.agent_manager/agent_paths
	else
		echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped agent paths of manager" >>$INSTALLERLOG
	fi
############################		
# Presentation
############################
	echo -e "\033[40m\033[40;31m\n\nFire\033[37mScope\033[33m Agent $VERSION Installer for $OSNAME\n=====================================================================================\n"
####################################################################################################
# Copy core files
####################################################################################################
	copycorefiles $COPYFROM $COPYTO
	echo "Copying Linux Agent Uninstaller script" >>$INSTALLERLOG
	`$CPEXE $CURDIR/firescope/agent/FireScope_Agent_Uninstall.sh $AGENTDIR/FireScope_Agent_Uninstall.sh >>$INSTALLERLOG`
####################################################################################################
# End - Copy core files
####################################################################################################

####################################################################################################
# Copy delegate files
####################################################################################################
	############################################################################################
	# Copy JMXDelegate
	############################################################################################
	`$CPEXE $JMX_INSTALL_FILES_DIR/jar/jmxdelegate.jar $AGENTDIR/modules/jmxdelegate/jar >>$INSTALLERLOG`
	############################################################################################
	# End - Copy JMXDelegate
	############################################################################################
####################################################################################################
# End - Copy delegate files
####################################################################################################

####################################################################################################
# chmod agent and agent manager bins
####################################################################################################
		$CHMODEXE +x $AGENTDIR/FireScope_Agent_Uninstall.sh >>$INSTALLERLOG
		$CHMODEXE +x $AGENTDIR/bin/firescope_agentd >>$INSTALLERLOG
		if [ "$SKIPAGENTMANAGER" != "1" ]; then
			`$CHMODEXE +x $MANAGERDIR/firescope_agent_managerd >>$INSTALLERLOG`
			`$CHMODEXE +x $MANAGERDIR/miniunzip >>$INSTALLERLOG`
			`$CHMODEXE +x $MANAGERDIR/minizip >>$INSTALLERLOG`
		fi
####################################################################################################
# End - chmod agent and agent manager bins
####################################################################################################
####################################################################################################
# Set some user input and collected values in config file
####################################################################################################
	###############################################
	# check for .conf and convert
	###############################################
		if [ -f $CONFIGFILEBASE/firescope_agentd.conf ]; then
			echo "### Conf upgrade conf --> xml ###" >>$INSTALLERLOG
				$AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd.conf -u "" >>$INSTALLERLOG
					echo 'Upgrading conf--->xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd.conf -u ""' >>$INSTALLERLOG
					echo "$DATE == $WHOAMI Server=$SERVER" >>$MANAGERDIR/.agent_manager/agent_paths
	###############################################
	# check for .xml and convert
	###############################################
	elif [ -f $CONFIGFILEBASE/firescope_agentd_posix.xml ]; then >>$INSTALLERLOG
		echo "### Conf upgrade xml --> xml ###"  >>$INSTALLERLOG
			$AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "" >>$INSTALLERLOG
				 echo 'Upgrading xml--->xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u ""' >>$INSTALLERLOG
				 echo "$DATE == $WHOAMI Server=$SERVER" >>$MANAGERDIR/.agent_manager/agent_paths
			echo "Upgrading old xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u JmxDelegateEnable=$JMX|JmxDelegatePort=$JPORT|JmxDelegateCommand=$JAVAPATH -Xms${JAVAMIN}m -Xmx${JAVAMAX}m|JmxDelegateParameters=-jar $AGENTDIR/modules/jmxdelegate/jar/jmxdelegate.jar &gt;/dev/null | SocketTimeoutMillisec=500" >>$INSTALLERLOG
				$AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "JmxDelegateParameters=-Xms${JAVAMIN}m -Xmx${JAVAMAX}m -jar $AGENTDIR/modules/jmxdelegate/jar/jmxdelegate.jar &gt;/dev/null" >>$INSTALLERLOG
 			echo "Upgrading old xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u UserParameter=oracle,/opt/firescope/agent/scripts/oracle/fireorav3" >>$INSTALLERLOG
 				$AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "UserParameter=oracle,/opt/firescope/agent/scripts/oracle/fireorav3" >>$INSTALLERLOG
	###############################################
	# create new config xml file
	###############################################
	else
		echo "### New Config XML Created ###" >>$INSTALLERLOG
		####################################################################################
		# New Config xml created
		####################################################################################
			echo "$DATE == $WHOAMI Server=$SERVER" >>$MANAGERDIR/.agent_manager/agent_paths
			echo "Building new xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd.conf -u AgentServiceName=firescope_agentd|AgentServiceStart=service firescope_agentd start|AgentServiceStop=service firescope_agentd stop" >>$INSTALLERLOG
				$AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "AgentServiceName=firescope_agentd|AgentServiceStart=service firescope_agentd start|AgentServiceStop=service firescope_agentd stop" >>$INSTALLERLOG
			echo "Building new xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u Server=$SERVER|ServerPort=$SPORT|Hostname=$CINAME|EnableRemoteCommands=$RMTCMD|DisableActive=$DACTIVE" >>$INSTALLERLOG
				$AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "Server=$SERVER|ServerPort=$SPORT|Hostname=$CINAME|EnableRemoteCommands=$RMTCMD|DisableActive=$DACTIVE|RunAsFireScop=$RUNASFIRESCOP" >>$INSTALLERLOG
			echo "Building new xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u ListenPort=$APORT|TempFileLocation=$AGENTDIR/cache|LogFile=$AGENTDIR/logs/firescope_agentd.log|PidFile=$AGENTDIR/logs/firescope_agentd.pid" >>$INSTALLERLOG
				$AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "ListenPort=$APORT|TempFileLocation=$AGENTDIR/cache|LogFile=$AGENTDIR/logs/firescope_agentd.log|PidFile=$AGENTDIR/logs/firescope_agentd.pid" >>$INSTALLERLOG
			echo "Building new xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u AgentImmediateMode=$REALTIME|AgentStoreDurationSeconds=$STORETIME|AgentStoreCount=$STORECOUNT" >>$INSTALLERLOG
				$AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "AgentImmediateMode=$REALTIME|AgentStoreDurationSeconds=$STORETIME|AgentStoreCount=$STORECOUNT" >>$INSTALLERLOG
			echo "Building new xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u ManagerPort=$MPORT|ManagerInstallationRoot=$MANAGERDIR|ManagerLogFile=$AGENTDIR/logs/firescope_agent_managerd.log|ManagerPidFile=$AGENTDIR/logs/firescope_agent_managerd.pid" >>$INSTALLERLOG
				$AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "ManagerPort=$MPORT|ManagerInstallationRoot=$MANAGERDIR|ManagerLogFile=$AGENTDIR/logs/firescope_agent_managerd.log|ManagerPidFile=$AGENTDIR/logs/firescope_agent_managerd.pid" >>$INSTALLERLOG
			echo "Building new xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u JmxDelegateEnable=$JMX|JmxDelegatePort=$JPORT|JmxDelegateCommand=$JAVAPATH|JmxDelegateParameters=-Xms${JAVAMIN}m -Xmx${JAVAMAX}m -jar $AGENTDIR/modules/jmxdelegate/jar/jmxdelegate.jar &gt;/dev/null | SocketTimeoutMillisec=500" >>$INSTALLERLOG
				$AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "JmxDelegateEnable=$JMX|JmxDelegatePort=$JPORT|JmxDelegateCommand=$JAVAPATH|JmxDelegateParameters=-Xms${JAVAMIN}m -Xmx${JAVAMAX}m -jar $AGENTDIR/modules/jmxdelegate/jar/jmxdelegate.jar &gt;/dev/null | SocketTimeoutMillisec=500" >>$INSTALLERLOG
 			echo "Building new xml $AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u UserParameter=oracle,/opt/firescope/agent/scripts/oracle/fireorav3" >>$INSTALLERLOG
 				$AGENTDIR/bin/firescope_agentd -c $CONFIGFILEBASE/firescope_agentd_posix.xml -u "UserParameter=oracle,/opt/firescope/agent/scripts/oracle/fireorav3" >>$INSTALLERLOG
	fi
		####################################################################################
		# Start - agent_init_sed
		####################################################################################
			uninstaller_sed
		####################################################################################
		# End - agent_init_sed
		####################################################################################

		####################################################################################
		# Start - agent_init_sed
		####################################################################################
			agent_init_sed
		####################################################################################
		# End - agent_init_sed
		####################################################################################

		####################################################################################
		# Start - agent_manager_init_sed
		####################################################################################
			if [ "$SKIPAGENTMANAGER" != "1" ]; then
				agent_manager_init_sed >>$INSTALLERLOG
			else
				echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER agent_manager_init_sed" >>$INSTALLERLOG
			fi
		####################################################################################
		# End - agent_manager_init_sed
		####################################################################################

####################################################################################################
# End - Set some user input and collected values in config file
####################################################################################################
####################################################################################################
# Copy agent version file
####################################################################################################
	echo "$INSTALLER" > $AGENTDIR/.agent/firescope_agentd_version
	if [ "$SKIPAGENTMANAGER" != "1" ]; then
		echo "$VERSION" > $MANAGERDIR/.agent_manager/firescope_agentd_manager_version
	fi
####################################################################################################
# Chown the firescope directory and all child directory to be owned by firescop
####################################################################################################
	`$CHOWNEXE -R $FSUSER:$FSGROUP $BASEDIR >>$INSTALLERLOG`
	if [ "$SKIPAGENTMANAGER" != "1" ]; then
		`$CHOWNEXE -R $FSMUSER:$FSMGROUP $MANAGERDIR >>$INSTALLERLOG`
	else
		echo "SKIPAGENTMANAGER=$SKIPAGENTMANAGER skipped chown of manager dir" >>$INSTALLERLOG
	fi
####################################################################################################
# Start - init_on_boot
####################################################################################################
init_on_boot
####################################################################################################
# End - init_on_boot
####################################################################################################
####################################################################################################
# Install Completed
####################################################################################################
	echo -e "\033[40m\033[40;31mFire\033[37mScope\033[33m Agent v$VERSION for $OSNAME has been installed.\n=====================================================================================\n"
	echo -e "\033[40m\033[40;33m\n\nStarting \033[31mFire\033[37mScope\033[33m Agent $VERSION for $OSNAME\n=====================================================================================\n\033[1m"
	`$SERVICEEXE firescope_agentd start >>$INSTALLERLOG`
	`$SLEEPEXE 5`
	if [ "$SKIPAGENTMANAGER" != "1" ]; then
#		echo -e "\nStarting FireScope Agent Manager $VERSION for $OSNAME\n========================================================\n"
			echo -e "\033[40m\033[40;33m\n\nStarting \033[31mFire\033[37mScope\033[33m Agent Manager $VERSION for $OSNAME\n=====================================================================================\n\033[1m"
			`$SERVICEEXE firescope_agent_managerd start >>$INSTALLERLOG`
	fi
	`$SLEEPEXE 5`
	AGENTSERVICE=`$PIDOFEXE firescope_agentd`
	if [ "$SKIPAGENTMANAGER" != "1" ]; then
		AGENTMANAGERSERVICE=`$PIDOFEXE firescope_agent_managerd`
	fi
		echo -e "\033[40m\033[40;31m\n\nFire\033[37mScope\033[33m Agent v$VERSION for $OSNAME installation and startup complete!!!.\n=====================================================================================\n\n"
		echo -e "\033[0m" # sets background back to default
exit 0
